# pydantic-containers

[![Build Status](https://travis-ci.org/AdityaGudimella/pydantic-containers.svg?branch=master)](https://travis-ci.org/AdityaGudimella/pydantic-containers)
[![codecov](https://codecov.io/gh/AdityaGudimella/pydantic-containers/branch/master/graph/badge.svg)](https://codecov.io/gh/AdityaGudimella/pydantic-containers)
[![PyPI version](https://badge.fury.io/py/pydantic-containers.svg)](https://badge.fury.io/py/pydantic-containers)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pydantic-containers.svg)](https://pypi.org/project/pydantic-containers/)
[![PyPI - License](https://img.shields.io/pypi/l/pydantic-containers.svg)](https://pypi.org/project/pydantic-containers/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/pydantic-containers.svg)](https://pypi.org/project/pydantic-containers/)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/AdityaGudimella/pydantic-containers/master?filepath=examples%2Fpydantic_containers.ipynb)

A collection of container types for pydantic that act like the built-in containers, but
can be serialized and deserialized using pydantic's `model_dump...` and `model_validate...` methods.
